@@ -12,9 +12,9 @@ import (
 	"k8s.io/klog"
 	"sigs.k8s.io/controller-runtime/pkg/client/config"
 
-	clusterclientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
-	"github.com/stolostron/rbac-query-proxy/pkg/proxy"
-	"github.com/stolostron/rbac-query-proxy/pkg/util"
+	"github.com/open-cluster-management/multicluster-observability-operator/proxy/pkg/proxy"
+	"github.com/open-cluster-management/multicluster-observability-operator/proxy/pkg/util"
+	clusterclientset "open-cluster-management.io/api/client/cluster/clientset/versioned"
 )
 
 const (
@@ -64,8 +64,7 @@ func main() {
 	go util.CleanExpiredProjectInfo(24 * 60 * 60)
 
 	http.HandleFunc("/", proxy.HandleRequestAndRedirect)
-	if err := http.ListenAndServeTLS(cfg.listenAddress, "/var/rbac_proxy/serving_certs/tls.crt",
-		"/var/rbac_proxy/serving_certs/tls.key", nil); err != nil {
+	if err := http.ListenAndServe(cfg.listenAddress, nil); err != nil {
 		klog.Fatalf("failed to ListenAndServe: %v", err)
 	}
 }
